'encoding UTF-8  Do not remove or change this line!
'*************************************************************************
'*
'*  OpenOffice.org - a multi-platform office productivity suite
'*
'*  $RCSfile: filename2.inc,v $
'*
'*  $Revision: 1.9 $
'*
'*  last change: $Author: jsk $ $Date: 2006/06/28 10:26:51 $
'*
'*  The Contents of this file are made available subject to
'*  the terms of GNU Lesser General Public License Version 2.1.
'*
'*
'*    GNU Lesser General Public License Version 2.1
'*    =============================================
'*    Copyright 2005 by Sun Microsystems, Inc.
'*    901 San Antonio Road, Palo Alto, CA 94303, USA
'*
'*    This library is free software; you can redistribute it and/or
'*    modify it under the terms of the GNU Lesser General Public
'*    License version 2.1, as published by the Free Software Foundation.
'*
'*    This library is distributed in the hope that it will be useful,
'*    but WITHOUT ANY WARRANTY; without even the implied warranty of
'*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
'*    Lesser General Public License for more details.
'*
'*    You should have received a copy of the GNU Lesser General Public
'*    License along with this library; if not, write to the Free Software
'*    Foundation, Inc., 59 Temple Place, Suite 330, Boston,
'*    MA  02111-1307  USA
'*
'/************************************************************************
'*
'* owner : joerg.skottke@sun.com
'*
'* short description : check the internal file dialog ( extended tests )
'*
'*******************************************************************************
'**
' #1 tSaveLoadDelFilesCJK    ' checks for strange names on windows that are allowed
' #1 tCJKFolders             ' checks if folders and files w. cjk chars are handled ok
'**
'\******************************************************************************

testcase tSaveLoadDelFilesCJK()

    '///<h1>Save, reload and delete files containing asian characters</h1>
    
    dim cStrangeName as string
    dim iCounter as integer ' iterator
    dim iRandom  as long    ' random number.(needs long for cjk chars)
    dim brc as boolean
    
    printlog( CHR$(13) )
    printlog( "Check if CJK-filenames are loaded/saved/deleted" )
    printlog( CHR$(13) )
    
    '///<ul>
    
    '///+<li>Open a new document</li>
    'printlog( "Open a new document" )
    'brc = hCreateDocument()
    
    '///+Save/Load/Delete files containing  permitted UNICODE/CJK-characters
    ' This test randomizes through a number of characters, a full test of all
    ' possible ascii characters would simply take too long.
    ' Note that the range of unified CJK characters lies between
    ' dec 19968 (#4E00) and dec 40879 (#9FAF) which makes a range of 20911
    ' different characters!
    printlog( CHR$(13) + "Names with CJK-chars" )
    printlog( "" )
    
    '///+<li>Invoke randomizer</li>
    call randomize()
    
    '///+<li>Repeat following steps for at least two asian characters:</li>
    '///<ul>
    for iCounter = 1 to 2
        
        iRandom = int( 19968 + ( 20911 * rnd ) )
        printlog( "" )
        printlog( " * Using decimal char: " & iRandom )
        
        '///+<li>Save file with trailing asian character and suffix</li>
        cStrangeName = hNameGen_append( iRandom , true )
        brc = hSaveLoadDelSuccess( cStrangeName , TRUE )
        
        '///+<li>Save file with leading asian character and suffix</li>
        cStrangeName = hNameGen_lead( iRandom , true )
        brc = hSaveLoadDelSuccess( cStrangeName , TRUE )
        
        '///+<li>Handle possible errormessages/warnings</li>
        kontext "active"
        if( active.exists() ) then
            qaerrorlog( "#i33964# Document does not exist when the last document is deleted from filepicker" )
            printlog( active.gettext() )
            active.ok()
        endif
        
    next iCounter
    '///</ul>
    
    '///+<li>Close the document</li>
    printlog( "Close the document" )
    brc = hDestroyDocument()
    '///</ul>
    
endcase

'*******************************************************************************

testcase tCJKFolders()

    '///<h1>Create and delete folders containing CJK characters</h1>
    
    '///<ul>
    
    dim cStrangeFolder as string
    dim cStrangeFile as string
    dim iCounter as integer ' iterator
    dim iRandom  as long    ' random number.(needs long for cjk chars)
    dim brc as boolean
    
    printlog( CHR$(13) )
    printlog( "Check if CJK-files/folders are handled ok" )
    printlog( CHR$(13) )
    
    '///+<li>Create a new document</li>
    printlog( "Open a new document" )
    brc = hCreateDocument()
    
    printlog( CHR$(13) + "Names with CJK-chars" )
    printlog( "" )
    
    '///+<li>Invoke randomizer</li>
    call randomize()
    
    '///+<li>Repeat following steps for at least three asian characters:</li>
    '///<ul>
    for iCounter = 1 to 3
        
        iRandom = int( 19968 + ( 20911 * rnd ) )
        printlog( " * Using decimal char: " & iRandom )
        
        '///+<li>Create a folder with a name containing cjk characters</li>
        cStrangeFolder = hNameGen_append( iRandom , false )
        brc = hCreateDirctoryExpectSuccess( cStrangeFolder )
        
        '///+<li>Save a file w. trailing cjk characters to the newly created directory</li>
        '///+<li>Load the file again</li>
        '///+<li>Delete the file</li>
        cStrangeFile = hNameGen_append( iRandom , true )
        cStrangeFile = convertpath( cStrangeFolder & "\" & cStrangeFile )
        brc = hSaveLoadDelSuccess( cStrangeFile , TRUE )
        
        '///+<li>Save a file w. leading cjk characters to the newly created directory</li>
        '///+<li>Load the file again</li>
        '///+<li>Delete the file</li>        
        cStrangeFile = hNameGen_lead( iRandom , true )
        cStrangeFile = convertpath( cStrangeFolder & "\" & cStrangeFile )
        brc = hSaveLoadDelSuccess( cStrangeName , true )
        
        '///+<li>Delete the folder</li>
        brc = hDeleteFileExpectSuccess( cStrangeFolder )
        
    next iCounter
    '///</ul>
    
    '///+<li>Close the document</li>
    printlog( "Close the document" )
    brc = hDestroyDocument()
    '///</ul>
    
endcase

